/*
	$Id: GroupData.java 5818 2011-10-21 11:15:41Z nicklas $

	Copyright (C) 2005 Johan Enell, Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Date;
import java.util.Set;
import java.util.HashSet;

/**
	This class holds information about a group.

	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.Group
	@see <a href="../../../../../../html/developer/api/data_api.authentication.html">Developer documentation: User authentication</a>
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (Fri, 21 Oct 2011) $
	@hibernate.class table="`Groups`" lazy="false"
*/
public class GroupData
	extends BasicData
	implements NameableData, RemovableData, SystemData, RegisteredData
{

	public GroupData()
	{}

	/*
		From the NameableData interface
		-------------------------------------------
	*/
	private String name;
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	private String description;
	public String getDescription()
	{
		return description;
	}
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------

	/*
		From the RemovableData interface
		-------------------------------------------
	*/
	private boolean removed;
	public boolean isRemoved()
	{
		return removed;
	}
	public void setRemoved(boolean removed)
	{
		this.removed = removed;
	}
	// -------------------------------------------

	/*
		From the SystemData interface
		-------------------------------------------
	*/
	private String systemId;
	public String getSystemId()
	{
		return systemId;
	}
	public void setSystemId(String systemId)
	{
		this.systemId = systemId;
	}
	// -------------------------------------------
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------

	private Set<UserData> users;
	/**
		Get the set that manages which users are members of this group.
		@hibernate.set table="`UserGroups`" lazy="true"
		@hibernate.collection-key column="`group_id`"
		@hibernate.collection-many-to-many column="`user_id`" class="net.sf.basedb.core.data.UserData"
	*/
	public Set<UserData> getUsers()
	{
		if (users == null) users = new HashSet<UserData>();
		return users;
	}
	void setUsers(Set<UserData> users)
	{
		this.users = users;
	}

	private Set<GroupData> children;
	/**
		Get the set that manages which other groups are members of this group.
		@hibernate.set table="`GroupGroups`" lazy="true"
		@hibernate.collection-key column="`parent_id`"
		@hibernate.collection-many-to-many column="`child_id`" class="net.sf.basedb.core.data.GroupData"
	*/
	public Set<GroupData> getChildren()
	{
		if (children == null) children = new HashSet<GroupData>();
		return children;
	}
	void setChildren(Set<GroupData> children)
	{
		this.children = children;
	}
	
	private Set<GroupData> parents;
	/**
		This is the inverse end.
		@see #getChildren()
		@hibernate.set table="`GroupGroups`" lazy="true"
		@hibernate.collection-key column="`child_id`"
		@hibernate.collection-many-to-many column="`parent_id`" class="net.sf.basedb.core.data.GroupData"
	*/
	Set<GroupData> getParents()
	{
		return parents;
	}
	void setParents(Set<GroupData> parents)
	{
		this.parents = parents;
	}

	private Set<ProjectData> projects;
	/**
		This is the inverse end.
		@see ProjectData#getGroups()
		@hibernate.set table="`GroupProjects`" lazy="true"
		@hibernate.collection-key column="`group_id`"
		@hibernate.collection-many-to-many column="`project_id`" class="net.sf.basedb.core.data.ProjectData"
	*/
	Set<ProjectData> getProjects()
	{
		return projects;
	}
	void setProjects(Set<ProjectData> projects)
	{
		this.projects = projects;
	}

	private Set<ItemKeyData> itemKeys;
	/**
		This is the inverse end.
		@see ItemKeyData#getGroups()
		@hibernate.set table="`GroupKeys`" lazy="true"
		@hibernate.collection-key column="`group_id`"
		@hibernate.collection-many-to-many column="`key_id`" class="net.sf.basedb.core.data.ItemKeyData"
	*/
	Set<ItemKeyData> getItemKeys()
	{
		return itemKeys;
	}
	void setItemKeys(Set<ItemKeyData> itemKeys)
	{
		this.itemKeys = itemKeys;
	}

	private QuotaData quota;
	/**
		Get the quota object which holds quota information for this group.
		@hibernate.many-to-one column="`quota_id`" not-null="false" outer-join="false"
	*/
	public QuotaData getQuota()
	{
		return quota;
	}
	public void setQuota(QuotaData quota)
	{
		this.quota = quota;
	}
	
	private boolean isDefault;
	/**
		If this group should be assigned to new users by default or not.
		@since 2.4
		@hibernate.property column="`is_default`" type="boolean" not-null="true"
	*/
	public boolean isDefault()
	{
		return isDefault;
	}
	public void setDefault(boolean isDefault)
	{
		this.isDefault = isDefault;
	}
	
	private boolean hiddenMembers;
	/**
		A flag indicating if members of the group should be hidden
		to each other or not.
		@since 2.13
		@hibernate.property column="`hidden_members`" type="boolean" not-null="true"
	*/
	public boolean getHiddenMembers()
	{
		return hiddenMembers;
	}
	public void setHiddenMembers(boolean hiddenMembers)
	{
		this.hiddenMembers = hiddenMembers;
	}
	
	
}
