/*
	$Id: IntegerParameterValueData.java 5818 2011-10-21 11:15:41Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.List;
import java.util.ArrayList;

/**
	Integer parameter value.

	@author Nicklas, Samuel
	@version 2.0
	@see <a href="../../../../../../html/developer/api/data_api.parameters.html">Developer documentation: Parameters</a>
	@hibernate.subclass discriminator-value="1"
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (Fri, 21 Oct 2011) $
*/
public class IntegerParameterValueData
	extends ParameterValueData<Integer>
{
	public IntegerParameterValueData()
	{}
	
	public IntegerParameterValueData(Integer... values)
	{
		super(values);
	}
	
	/**
		@return 1 (Type.INT)
		@since 2.16
	*/
	public int getValueType()
	{
		return 1;
	}

	private List<Integer> values;
	/**
		@hibernate.bag table="`IntegerValues`" lazy="true" cascade="all"
		@hibernate.collection-key column="`id`"
		@hibernate.collection-element column="`value`" type="int" not-null="true"
	*/
	public List<Integer> getValues()
	{
		if (values == null)
		{
			values = new ArrayList<Integer>();
		}
		return values;
	}
	void setValues(List<Integer> values)
	{
		this.values = values;
	}

	public String toString()
	{
		return values.toString();
	}
}
