/*
  $Id: ReporterListScoreData.java 5818 2011-10-21 11:15:41Z nicklas $

	 Copyright (C) 2006 Nicklas Nordborg, Martin Svensson
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.
	
	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

/**
	This class holds information about the score of a reporter in a 
	reporter list. The mapping is defined in the external mapping
	file <code>ReporterListScoreData.hbm.xml</code> since
	XDoclet can't generate the <code>&lt;composite-id&gt;</code>
	tag for us.
 
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.ReporterList
	@see <a href="../../../../../../html/developer/api/data_api.reporters.html">Developer documentation: Reporters</a>
*/
public class ReporterListScoreData
	implements Serializable
{

	private static final long serialVersionUID = 4579749871479306251L;
	public ReporterListScoreData()
	{}
	
	/*
		From the Object class
		-------------------------------------------
	*/	
	@Override
	public boolean equals(Object o)
	{
		if (this == o) return true;
		if (o == null || getClass() != o.getClass()) return false;
		ReporterListScoreData other = (ReporterListScoreData)o;
		return reporterList.equals(other.reporterList) && reporterId == other.reporterId;
	}
	@Override
	public int hashCode()
	{
		return 23 * reporterList.hashCode() + 7 * reporter.hashCode();
	}
	public String toString()
	{
		return "ReporterListScoreData: reporterId="+getReporterId()+"; score="+getScore();
	}
	// -------------------------------------------
	
	private transient ReporterListData reporterList;
	/**
		The reporter list this reporter and score belongs to. Part
		of the composite id of this class.
	*/
	public ReporterListData getReporterList()
	{
		return reporterList;
	}
	public void setReporterList(ReporterListData reporterList)
	{
		this.reporterList = reporterList;
	}
	
	private int reporterId;
	/**
	 	The id of the reporter. This mapping is neccessary
	 	since the alternative <code>&lt;key-many-to-one&gt;</code>
	 	doesn't work with <code>INNER JOIN FETCH</code> queries.
	 	We have to use a regular <code>&lt;many-to-one&gt;</code>,
	 	which means that the reporter property must be outside the
	 	composite id.
	*/
	public int getReporterId()
	{
		return reporterId;
	}
	public void setReporterId(int reporterId)
	{
		this.reporterId = reporterId;
	}
	
	private transient ReporterData reporter;
	/**
		Get the reporter.
	*/
	public ReporterData getReporter()
	{
		return reporter;
	}
	public void setReporter(ReporterData reporter)
	{
		this.reporter = reporter;
		reporterId = reporter.getId();
	}

	private Float score;
	/**
		Get the score for the reporter, or null if no score has been set.
	*/
	public Float getScore()
	{
		return score;
	}
	public void setScore(Float score)
	{
		this.score = score;
	}

	private void readObject(ObjectInputStream ois)
		throws ClassNotFoundException, IOException 
	{
		ois.defaultReadObject();
		int reporterListId = ois.readInt();
		reporterList = new ReporterListData();
		reporterList.setId(reporterListId);
		reporter = new ReporterData(reporterId);
	}
	private void writeObject(ObjectOutputStream ois)
		throws IOException 
	{
		ois.defaultWriteObject();
		ois.writeInt(reporterList.getId());
	}

	
}
