/*
	$Id: VirtualDbData.java 5818 2011-10-21 11:15:41Z nicklas $
	
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This class holds information about a virtual database in the
	dynamic part of Base.
	
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.VirtualDb
	@see <a href="../../../../../../html/developer/api/data_api.experiments.html">Developer documentation: Experiments and analysis</a>
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (Fri, 21 Oct 2011) $
	@hibernate.class table="`VirtualDbs`" lazy="true"
*/
public class VirtualDbData
	extends BasicData
{
	public VirtualDbData()
	{}

	private ExperimentData experiment;
	/**
		Get the experiment that stores it's data in this virtual database.
		@hibernate.one-to-one property-ref="virtualDb"
		@see ExperimentData#getVirtualDb()
	*/
	public ExperimentData getExperiment()
	{
		return experiment;
	}
	void setExperiment(ExperimentData experiment)
	{
		this.experiment = experiment;
	}

	private short cubes;
	/**
		The number of data cubes in the virtual database. Updates
		to this column are done through SQL statements and not
		through this object.
		@hibernate.property column="`cubes`" type="short" not-null="true" update="false"
	*/
	public short getCubes()
	{
		return cubes;
	}
	public void setCubes(short cubes)
	{
		this.cubes = cubes;
	}

	private short mappings;
	/**
		The number of cube mappings in the virtual database.
		@hibernate.property column="`mappings`" type="short" not-null="true"
	*/
	public short getMappings()
	{
		return mappings;
	}
	public void setMappings(short mappings)
	{
		this.mappings = mappings;
	}
	
	private Set<DataCubeData> dataCubes;
	/**
		This is the inverse end.
		@see DataCubeData#getVirtualDb()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`virtualdb_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.DataCubeData"
	*/
	Set<DataCubeData> getDataCubes()
	{
		return dataCubes;
	}
	void setDataCubes(Set<DataCubeData> dataCubes)
	{
		this.dataCubes = dataCubes;
	}

}
