/*
	$Id: AboutImpl.java 5607 2011-04-15 07:52:28Z nicklas $

	Copyright (C) 2005 Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.plugin;

/**
	A simple implementation of the {@link About} interface.

	@base.modified $Date$
	@author Enell
	@version 2.0
*/
public class AboutImpl implements About
{
	private final String name;
	private final String description;
	private final String version;
	private final String minBaseVersion;
	private final String maxBaseVersion;
	private final String copyright;
	private final String contact;
	private final String email;
	private final String url;
	
	
	/**
		Create a new about object without any min or max BASE version requirement.
	*/
	public AboutImpl(String name, String description, String version, String copyright, String contact, String email, String url)
	{
		this(name, description, version, null, null, copyright, contact, email, url);
	}

	
	/**
		Create a new {@link About} object.

		@param name The name of the plugin, null not allowed
		@param description A description of the plugin
		@param version The version of the plugin
		@param minBaseVersion The minium version of BASE that is required by the plugin
		@param maxBaseVersion The maxium version of BASE that the plugin is expected to work with
		@param copyright A copyright notice
		@param contact Contact information for the plugin
		@param email An email adress to get more information about the plugin
		@param url An URL to get more inforamtion about the plugin
		@throws NullPointerException If the name is null
		@since 3.0
	*/
	public AboutImpl(String name, String description, String version, String minBaseVersion, String maxBaseVersion, String copyright, String contact, String email, String url)
	{
		if (name == null) throw new NullPointerException("The 'name' parameter mustn't be null.");
		this.contact = contact;
		this.copyright = copyright;
		this.description = description;
		this.email = email;
		this.name = name;
		this.url = url;
		this.version = version;
		this.minBaseVersion = minBaseVersion;
		this.maxBaseVersion = maxBaseVersion;
	}

	/*
		From the About interface
		-------------------------------------------
	*/
	@Override
	public String getContact()
	{
		return contact;
	}

	@Override
	public String getCopyright()
	{
		return copyright;
	}

	@Override
	public String getDescription()
	{
		return description;
	}

	@Override
	public String getEmail()
	{
		return email;
	}

	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public String getUrl()
	{
		return url;
	}

	@Override
	public String getVersion()
	{
		return version;
	}
	
	@Override
	public String getMinBaseVersion() 
	{
		return minBaseVersion;
	}
	
	@Override
	public String getMaxBaseVersion() 
	{
		return maxBaseVersion;
	}
	// -------------------------------------------
}
