/**
	$Id: AnalysisFilterPlugin.java 4516 2008-09-11 20:09:17Z jari $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.plugin;

/**
	This is a tagging interface that should be used by all analysis plug-ins that
	are filtering data only. The plug-in should not create new intensity values or
	extra values, or some other values. A typical code example uses a 
	{@link net.sf.basedb.core.FilterBatcher}
	to store the filtered data.

	<pre class="code">
DbControl dc = sc.newDbControl();
try
{
   BioAssaySet source = getSourceBioAssaySet(dc);
   String filterMethod = ... // Something that explains the filter...
   Transformation t = source.newTransformation(job);
   dc.saveItem(t);

   // Create the filtered BioAssaySet in the same datacube and layer
   BioAssaySet child = t.newProduct(null, null, false);
   child.setName("Filter: " + filterMethod);
   dc.saveItem(child);

   // Create the batcher
   FilterBatcher filterBatcher = child.getFilterBatcher();
   while (we_have_more_data)
   {
      filterBatcher.insert(...);
   }
   dc.commit();
}
finally
{
  if (dc != null) dc.close();
}
</pre>

	@author nicklas
	@version 2.4
	@base.modified $Date: 2008-09-11 22:09:17 +0200 (Thu, 11 Sep 2008) $
*/
public interface AnalysisFilterPlugin
	extends Plugin
{}
