/*
	$Id: HqlEntityExpression.java 5320 2010-04-21 09:48:29Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Johan Enell

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Collection;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.data.BasicData;

/**
	An expression representing a Hibernate entity.
	<p>
	Throws an <code>UnsupportedOperationException</code> if 
	{@link Query#getQueryType()} isn't {@link QueryType#HQL}.

	@author Nicklas
	@version 2.0
	@see Hql#entity(BasicItem)
	@see Hql#entity(BasicData)
	@base.modified $Date: 2010-04-21 11:48:29 +0200 (Wed, 21 Apr 2010) $
*/
public class HqlEntityExpression
	implements Expression
{
	private final int id;
	private final Object item;

	HqlEntityExpression(BasicItem item)
	{
		this.id = item.getId();
		this.item = item;
	}
	
	/**
		@since 2.2.2
	*/
	HqlEntityExpression(BasicData data)
	{
		this.id = data.getId();
		this.item = data;
	}

	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	public String toQl(Query query, DbControl dc)
		throws BaseException
	{
		if (query.getQueryType() == QueryType.HQL)
		{
			return Integer.toString(id);
		}
		else
		{
			throw new UnsupportedOperationException("'entity' operation not supported by "+query.getQueryType()+" query.");
		}
	}
	/**
		@return Always null
	*/
	public Collection<? extends QueryElement> getChildren()
	{
		return null;
	}
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return item.toString();
	}
	/**
		This expression is equal to another HqlEntityExpression if they 
		represent the same item.
	*/
	@Override
	public boolean equals(Object other)
	{
		if (this == other) return true;
		if (other == null || this.getClass() != other.getClass()) return false;
		HqlEntityExpression o = (HqlEntityExpression)other;
		return item.equals(o.item);
	}
	@Override
	public int hashCode()
	{
		return item.hashCode();
	}
	// -------------------------------------------
}
