/*
	$Id: Restriction.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import net.sf.basedb.core.Type;

/**
	A restriction query element. This is a query element that can appear
	in the <code>WHERE</code> and <code>HAVING</code> part of a {@link Query}.
	Typically a restriction consists of a condition which must be true for a
	row if it should be returned. For example:
<pre class="code">
SELECT ...
FROM ...
WHERE id = 2
</pre>

	<p>
	Implementation note! Do not create restrictions that use user input directly
	in the queries. Always create a parameter ({@link Expressions#parameter(String)} 
	and use the {@link Query#setParameter(String, Object, Type)} method to specify the value.
	Using parameters also makes it possible to execute the same query multiple times
	with different parameter values.
	
<pre class="code">
ItemQuery&lt;User&gt; query = User.getQuery();
query.restrict(
   Restrictions.eq(
      Hql.property("name"),
      Expressions.parameter("name")
   )
);

// Generated HQL
SELECT usr
FROM UserData usr
WHERE usr.name = :name

query.setParameter("name", "Nicklas");
List<User> nicklasList = query.list(dc);

query.setParameter("name", "Johan");
List<User> johanList = query.list(dc);
</pre>

	<p>
	Restrictions can be created by the {@link Restrictions} factory class.

	@author Nicklas
	@version 2.0
	@see Restrictions
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (Mon, 06 Apr 2009) $
*/
public interface Restriction
	extends QueryElement
{}
