/*
	$Id: SumExpression.java 5320 2010-04-21 09:48:29Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Collection;
import java.util.Collections;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.BaseException;
import net.sf.basedb.util.EqualsHelper;

/**
	Calculates the sum of an expression: SUM(e)

	@author Nicklas
	@version 2.0
	@see Aggregations#mean(Expression)
	@base.modified $Date: 2010-04-21 11:48:29 +0200 (Wed, 21 Apr 2010) $
*/
public class SumExpression
	implements Expression 
{
	private final Expression e;

	SumExpression(Expression e)
	{
		assert e != null : "e == null";
		this.e = e;
	}

	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	public String toQl(Query query, DbControl dc)
		throws BaseException
	{
		return "SUM(" + e.toQl(query, dc) + ")";
	}
	/**
		@return The expression to sum
	*/
	public Collection<? extends QueryElement> getChildren()
	{
		return Collections.singleton(e);
	}
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return "SUM(" + e + ")";
	}
	/**
		This expression is equal to another SumExpression if their 
		child expressions are equal.
	*/
	@Override
	public boolean equals(Object other)
	{
		if (this == other) return true;
		if (other == null || this.getClass() != other.getClass()) return false;
		SumExpression o = (SumExpression)other;
		return EqualsHelper.equals(e, o.e);
	}
	@Override
	public int hashCode()
	{
		return EqualsHelper.hashCode(e) + getClass().hashCode();
	}
	// -------------------------------------------
}

