/**
	$Id: EncodeUtil.java 5434 2010-09-30 08:53:05Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.encode;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
	Utility functions for encoding/decoding strings.

	@author Nicklas
	@since 2.16
	@base.modified $Date: 2010-09-30 10:53:05 +0200 (Thu, 30 Sep 2010) $
*/
public class EncodeUtil
{

	/**
		Encode all strings in a collection.
		@param values A collection with values that should be encoded
		@param encoder The encoder implemenation to use
		@return A list with the encoded values
	*/
	public static List<String> encodeAll(Collection<String> values, EncoderDecoder encoder)
	{
		List<String> encoded = new ArrayList<String>(values.size());
		for (String s : values)
		{
			encoded.add(encoder.encode(s));
		}
		return encoded;
	}
	
	/**
		Decode all strings in a collection.
		@param values A collection with values that should be decoded
		@param decoder The decoder implemenation to use
		@return A list with the decoded values
	*/
	public static List<String> decodeAll(Collection<String> values, EncoderDecoder decoder)
	{
		List<String> decoded = new ArrayList<String>(values.size());
		for (String s : values)
		{
			decoded.add(decoder.decode(s));
		}
		return decoded;
	}

	
	/**
		Encode all strings in a collection and join them into a single
		string.
		
		@param values A collection with values that should be encoded
		@param encoder The encoder implemenation to use
		@param separator The separator string that is inserted between the decoded values
		@param skipNull TRUE to skip null values (before and after encoding)
		@return A string with the encoded values joined together
	*/
	public static String encodeAndJoin(Collection<String> values, EncoderDecoder encoder, String separator, boolean skipNull)
	{
		StringBuilder sb = new StringBuilder();
		boolean firstElement = true;
		for (String s : values)
		{
			if (s == null && skipNull) continue;
			s = encoder.encode(s);
			if (s == null && skipNull) continue;
			if (!firstElement) sb.append(separator);
			sb.append(s);
			firstElement = false;
		}
		return sb.toString();
	}
	
}
