/**
	$Id: MarkAsProcessedProcessor.java 5603 2011-04-08 12:50:27Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.manager.processor;

import net.sf.basedb.util.extensions.manager.ExtensionsFileProcessor;
import net.sf.basedb.util.extensions.manager.ExtensionsManager;
import net.sf.basedb.util.extensions.manager.ExtensionsFile.WriteableExtensionsFile;

/**
	File processor implementation that marks all extension files
	as processed. This should cause them not to be processed again
	unless they have been modified or deleted.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-08 14:50:27 +0200 (Fri, 08 Apr 2011) $
*/
public class MarkAsProcessedProcessor
	implements ExtensionsFileProcessor
{

	private int numFiles;
	
	public MarkAsProcessedProcessor()
	{}
	
	/*
		From the ExtensionsFileProcessor interface
		------------------------------------------
	*/
	@Override
	public void begin(ExtensionsManager manager, int numFiles)
	{
		this.numFiles = 0;
	}
	
	@Override
	public void processFile(ExtensionsManager manager, WriteableExtensionsFile wFile)
	{
		numFiles++;
		wFile.markAsProcessed();
	}

	@Override
	public void done(ExtensionsManager manager)
	{}

	@Override
	public void done(ExtensionsManager manager, Throwable t)
	{}
	// ---------------------------------------------

	/**
		Get the number of files that was processed.
	*/
	public int getNumFiles()
	{
		return numFiles;
	}

	
}
