/*
	$Id: TestGtfInputStream.java 5770 2011-09-29 11:27:33Z nicklas $

	BioArray Software Environment (BASE) - http://base.thep.lu.se/
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg

	This file is part of BASE.

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import java.io.InputStream;
import java.util.regex.Pattern;

import net.sf.basedb.util.FileUtil;
import net.sf.basedb.util.gtf.GtfInputStream;
import net.sf.basedb.util.parser.FlatFileParser;

public class TestGtfInputStream
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing GTFInputStream");
		
		test_parse("data/test.gtf", 
			"\\<transcript_id>\\@\\<seqname>\\", "\\<source>\\", "\\<gene_id>\\", "\\<gene_name2>\\");

		write("++Testing GTFInputStream "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static void write(String message)
	{
		System.out.println(message);
	}
	
	static void test_parse(String file, String... mappings)
	{
		try
		{
			FlatFileParser ffp = new FlatFileParser();
			ffp.setDataHeaderRegexp(Pattern.compile("\\<seqname\\>.*"));
			ffp.setDataSplitterRegexp(Pattern.compile("\\t"));
			ffp.setMinDataColumns(4);
			ffp.setMaxDataColumns(-1);
			
			InputStream gtf = new GtfInputStream(FileUtil.getInputStream(new java.io.File(file)), "ISO-8859-1", true);
			TestFlatFileParser.test_parse(ffp, file, gtf, mappings);
			if (!TestFlatFileParser.ok)
			{
				ok = false;
			}
		}
		catch (Throwable ex)
		{
			write("--Parse FAILED (" + file + ")");
			ex.printStackTrace();
			ok = false;
		}
	}

}

